@@ -79,8 +79,8 @@ def language_server(
     try:
         profile = (
             load_robot_config_from_path(*config_files)
-            .combine_profiles(*(app.config.profiles or []), verbose_callback=app.verbose)
-            .evaluated()
+            .combine_profiles(*(app.config.profiles or []), verbose_callback=app.verbose, error_callback=app.error)
+            .evaluated_with_env(verbose_callback=app.verbose, error_callback=app.error)
         )
     except (TypeError, ValueError) as e:
         app.echo(str(e), err=True)
